@@ -117,6 +117,9 @@ enum { MP_ed_mira_automatic_contig_editing=1000,
        MP_as_clip_badsolexaends,
        MP_as_search_phix174,
        MP_as_filter_phix174,
+       MP_as_filter_rrna,
+       MP_as_filter_rrna_pairs,
+       MP_as_filter_rrna_numkmers,
        MP_as_clip_knownadaptorsright,
        MP_as_clip_possible_vectors,
        MP_as_clip_vector_maxlenallowed,
@@ -170,7 +173,6 @@ enum { MP_ed_mira_automatic_contig_editing=1000,
        MP_as_backbone_strainname_forceforall,
        MP_as_backbone_rail_fromstrain,
        MP_as_startbackboneusage_inpass,
-       MP_as_backbone_alsobuildnewcontigs,
        MP_as_backbone_trimoverhangingreads,
        MP_as_backbone_bootstrapnewbackbone,
 
@@ -200,7 +202,7 @@ enum { MP_ed_mira_automatic_contig_editing=1000,
        MP_hs_nastyrepeatcoverage,
        MP_hs_repeatlevel_in_infofile,
        MP_hs_applydigitalnormalisation,
-       MP_hs_million_hashes_per_buffer,
+       MP_hs_memtouse,
        MP_hs_rare_kmer_final_kill,
 
        MP_al_bip=5500,
@@ -249,6 +251,7 @@ enum { MP_ed_mira_automatic_contig_editing=1000,
        MP_con_min_readspergroup,
        MP_con_min_rmb_neighbourqual,
        MP_con_min_groupqual_for_rmb_tagging,
+       MP_con_min_coverage_percentage,
 //       MP_con_min_groupqual_for_wrmbsrmb_change,
        MP_con_endread_mark_exclusion_area,
        MP_con_emea_setzero_on_clipping_pec,
@@ -316,6 +319,7 @@ enum { MP_ed_mira_automatic_contig_editing=1000,
        MP_jobdef_genome,
        MP_jobdef_est,
        MP_jobdef_fragments,
+       MP_jobdef_clustering,
        MP_jobdef_estsnppipeline1,
        MP_jobdef_estsnppipeline2,
        MP_jobdef_estsnppipeline3,
